==> lxqt-panel-0.9.0.tar.xz: lxqt-panel-0.9.0/plugin-cpuload/translations/cpuload_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>LxQtCpuLoad</name>
    <message>
        <source>Cpu load %1%</source>
        <translation type="vanished">Uporaba CPE: %1 %</translation>
    </message>
    <message>
        <location filename="../lxqtcpuload.cpp" line="119"/>
        <source>CPU load %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxQtCpuLoadConfiguration</name>
    <message>
        <source>LxQt Cpu Load settings</source>
        <translation type="vanished">Nastavitve prikaza uporabe CPE za LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Splošno</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Pokaži besedilo</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Hitrost osveževanja:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Usmerjenost vrstice:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>Od spodaj navzgor</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>Od zgoraj navzdol</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>Iz leve proti desni</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>Iz desne proti levi</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-cpuload/translations/cpuload_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="127"/>
        <source>CPU load %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Splošno</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Pokaži besedilo</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Hitrost osveževanja:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Usmerjenost vrstice:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>Od spodaj navzgor</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>Od zgoraj navzdol</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>Iz leve proti desni</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>Iz desne proti levi</translation>
    </message>
</context>
</TS>
